/*  Alien Pool
    Copyright (C) 2003  Michael J. Korman <mike@taequin.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @file Alien.hh
 * Interface of the Alien class.
 */

#ifndef ALIEN_HH
#define ALIEN_HH

#include "Sprite.hh"

/**
 * Class to represent aliens.
 */
class Alien : public Sprite {
public:
    Alien(SpriteBase* base1, SpriteBase* base2, SDL_Surface* scr, SDL_Surface* bckgrnd, 
          float xvel, float yvel, int angle);
    ~Alien();

    const SpriteBase* get_base1();
    const SpriteBase* get_base2();
    const ALIEN_STATE get_state();
    const int get_trajectory();
    const SpriteBase* get_bullet_base();

    void set_base1(SpriteBase* base1);
    void set_base2(SpriteBase* base2);
    void set_state(ALIEN_STATE state);
    void set_trajectory(int trajectory);
    void set_bullet_base(SpriteBase* bullet_base);

    bool go();
    void hit();
    void shoot();

private:
    SpriteBase* _base1; /**< Sprite base for normal aliens. */
    SpriteBase* _base2; /**< Sprite base for dumb aliens. */
    ALIEN_STATE _state; /**< State of the alien. */
    int _trajectory; /**< Current angle. */
    SpriteBase* _bullet_base; /**< Sprite base for bullets. */

    int _counter; /**< When this reaches 0, alien changes direction. */
    int _dumb_counter; /**< When this reaches 0, dumb alien dies. */
    int _shoot_counter; /**< When this reaches 0, alien shoots. */
};

#endif // ALIEN_HH
