/*  Alien Pool
    Copyright (C) 2003  Michael J. Korman <mike@taequin.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @file Bullet.cc
 * Implementation of the Bullet class.
 */

#include <cmath>

#include "Bullet.hh"

/**
 * Constructor.
 * @param sb the sprite base.
 * @param scr the screen surface.
 * @param bckgrnd the background surface.
 * @param vel the initial velocity.
 * @param angle the initial angle.
 */
Bullet::Bullet(SpriteBase* sb, SDL_Surface* scr, SDL_Surface* bckgrnd, 
               float xvel, float yvel, int angle)
    : Sprite(sb, scr, bckgrnd, xvel, yvel, angle)
{
    _ttl = BULLET_TTL;
}

/**
 * Destructor. Draws the background over the current image.
 */
Bullet::~Bullet()
{
    update_background();
}

/**
 * Moves the bullet one step. If the bullet collides with the edge of the screen,
 * performs the necessary modifications to the trajectory for a bounce.
 */
void Bullet::go()
{
    int new_x = _x + int(round_to_int(_xvel * cos((M_PI/180) * _trajectory)));
    int new_y = _y - int(round_to_int(_yvel * sin((M_PI/180) * _trajectory)));
    
    move(new_x, new_y);

    if (new_y < 0 || new_y > (SCREEN_HEIGHT - _sprite_base->get_height())) {
        _trajectory *= -1;
    }
    if (new_x > (SCREEN_WIDTH - _sprite_base->get_width()) || new_x < 0) {
        _trajectory = 180 - _trajectory;
    }

    _ttl--;
}

/**
 * Gets the trajectory.
 * @return the trajectory.
 */
const int Bullet::get_trajectory()
{
    return _trajectory;
}

/**
 * Gets the time-to-live of the bullet.
 * @return the time-to-live.
 */
const int Bullet::get_ttl()
{
    return _ttl;
}

/**
 * Sets the trajectory.
 * @param trajectory the new trajectory.
 */
void Bullet::set_trajectory(int trajectory)
{
    _trajectory = trajectory;
}

