/*  Alien Pool
    Copyright (C) 2003  Michael J. Korman <mike@taequin.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @file Sprite.hh
 * Interface of the Sprite class.
 */

#ifndef SPRITE_HH
#define SPRITE_HH

#include <SDL/SDL.h>
#include <string>
#include <vector>

#include "common.hh"
#include "SpriteBase.hh"

/**
 * Class to represent sprites. This class will be usually be derived from 
 * when an actual sprite needs to be created.
 */
class Sprite {
public:
    Sprite(SpriteBase* sb, SDL_Surface* scr, SDL_Surface* bckgrnd, 
           float xvel, float yvel, int angle);
    ~Sprite();

    const bool collide(Sprite* other);
    const bool out_of_bounds(int x, int y);

    SpriteBase* get_sprite_base() const;
    const int get_x();
    const int get_y();
    const float get_xvel();
    const float get_yvel();
    const SDL_Surface* get_picture();
    const SDL_Surface* get_screen();
    const SDL_Surface* get_background();
    const int get_angle();

    void set_sprite_base(SpriteBase* sb);
    void set_x(int x);
    void set_y(int y);
    void set_xvel(float xvel);
    void set_yvel(float yvel);
    void set_picture(SDL_Surface* picture);
    void set_screen(SDL_Surface* scrn);
    void set_background(SDL_Surface* bckgrnd);
    void set_angle(int angle);

    void incr_angle();
    void decr_angle();

    void move(int x, int y);
    void update_background();
    
    virtual void draw(int new_x, int new_y);

protected:
    SpriteBase* _sprite_base; /**< Associated sprite base. */
    int _x; /**< The x-coordinate of the sprite. */
    int _y; /**< The y-coordinate of the sprite. */
    float _xvel; /**< The velocity of the sprite. */
    float _yvel; /**< The velocity of the sprite. */
    SDL_Surface* _picture; /**< The current displayed image. */
    SDL_Surface* _screen; /**< The screen surface. */
    SDL_Surface* _background; /**< The background surface. */
    int _angle; /**< The angle of the sprite. */
};

#endif // SPRITE_HH
