/*  Alien Pool
    Copyright (C) 2003  Michael J. Korman <mike@taequin.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @file SpriteBase.hh
 * Interface of the SpriteBase class.
 */

#ifndef SPRITEBASE_HH
#define SPRITEBASE_HH

#include <string>
#include <vector>

#include <SDL/SDL.h>

/**
 * Class to represent a sprite base. A sprite base contains all of the
 * surfaces that are associated with a particular type of sprite. All 
 * sprites of the same type share one sprite base. This eliminates the 
 * wasting of memory due to duplicate copies of each image being stored 
 * in the individual sprites, if sprites have images in common.
 */
class SpriteBase {
public:
    SpriteBase(std::string dir_name, SDL_Surface* screen);
    ~SpriteBase();

    const std::vector<SDL_Surface*> get_images();
    const int get_image_count();
    const int get_width();
    const int get_height();

    void set_images(std::vector<SDL_Surface*> images);
    void set_image_count(int image_count);
    void set_width(int width);
    void set_height(int height);

private:
    std::vector<SDL_Surface*> _images; /**< Vector of all images 
                                          making up this sprite base. */

    int _image_count; /**< Number of images in the sprite base. */
    int _width; /**< Width of each image. */
    int _height; /**< Height of each image. */
};

#endif // SPRITEBASE_HH
